@@ -439,7 +439,7 @@ class GUI(Tk):
 			self.dump_config()
 		fourcc = cv2.VideoWriter_fourcc(*'mp4v')
 		out = cv2.VideoWriter(os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'.mp4', fourcc, self.cfg['fr']*self.cfg['speed']/100, tuple(self.data['W_shape'][::-1][1:]),True)
-		nframes = len(self.data['H_fp'].T)
+		nframes = len(self.data['H_pp'].T)
 		for i in range(nframes):
 			frame = (self.data['W_pp']@np.diag(self.data['H_pp'][:,i])@self.cmap[:,:-1]*(255/self.cfg['brightness'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8')
 			out.write(cv2.cvtColor(frame, cv2.COLOR_RGB2BGR))
